@@ -1,13 +1,12 @@
 #' Get the citation Red List API version
 #'
 #' @export
-#' @param key A IUCN API token
-#' @param ... Curl options passed to \code{\link[httr]{GET}}
+#' @param ... Curl options passed to \code{\link[crul]{HttpClient}}
 #' @return API citation as character string
 #' @examples \dontrun{
 #' rl_citation()
 #' }
-rl_citation <- function(key = NULL, ...) {
+rl_citation <- function(...) {
   sprintf('IUCN 2015. IUCN Red List of Threatened Species. Version %s <www.iucnredlist.org>',
-          rl_version(key, ...))
+          rl_version(...))
 }
