@@ -14,15 +14,18 @@
 #' rl_sp_country_('NZ')
 #'
 #' # curl options
-#' library("httr")
-#' res <- rl_sp_country('NZ', config=verbose())
+#' res <- rl_sp_country('NZ', verbose = TRUE)
 #' }
 rl_sp_country <- function(country, key = NULL, parse = TRUE, ...) {
+  assert_is(parse, 'logical')
   rl_parse(rl_sp_country_(country, key, ...), parse)
 }
 
 #' @export
 #' @rdname rl_sp_country
 rl_sp_country_ <- function(country, key = NULL, ...) {
+  assert_is(key, 'character')
+  assert_is(country, 'character')
+  assert_n(country, 1)
   rr_GET(file.path("country/getspecies", country), key, ...)
 }
